## load the packages
library(dplyr)
library(ggplot2)
library(tidyverse)
library(microsynth)
library(corrplot)

## load the data
# microsynth comes with a built-in data set from seattle
data("seattledmi", package = "microsynth")
class(seattledmi)
str(seattledmi)

### 1. Understanding the data ###
# explore the data
head(seattledmi,6)
colnames(seattledmi)

summary(seattledmi)

# These data are already all numeric and have the intervention variable labeled
# everything is really already as we need it to be!


# convert Intervention to factor for proper estimation of correlation
seattledmi$Intervention <- as.factor(seattledmi$Intervention)
model.matrix(~0+., data=seattledmi) %>%
  cor(use="pairwise.complete.obs") %>%
  ggcorrplot(show.diag=FALSE, type="lower", lab=TRUE, lab_size=2)

# convert Intervention back to numeric as microsynth function could only deal with numerics
seattledmi$Intervention <- as.numeric(seattledmi$Intervention)
class(seattledmi$Intervention)

### 2. Setting up key parameters ###

#Treatment and synthetic control will matched on block-level Census demographic data: 
#each block’s population, black residents, hispanic residents, males aged 15-21, 
#the number of households, the number of families per household, the number of female-led households, 
#the number of households that are renters, and the number of vacant houses. 
#As these variables are all time-invariant, they will be set to "match.covar".

cov.var <- c("TotalPop", "BLACK", "HISPANIC", "Males_1521", "HOUSEHOLDS", 
             "FAMILYHOUS", "FEMALE_HOU", "RENTER_HOU", "VACANT_HOU")

#The outcome variable is any criminal arrest.
match.out <- c("any_crime")

### 3. Running a basic microsynth model ###

set.seed(123456)

sea1 <- microsynth(seattledmi, idvar = "ID", timevar = "time",
                   intvar = "Intervention", start.pre = 1, end.pre = 12,
                   end.post = 16, match.out = match.out, match.covar = cov.var, 
                   result.var = match.out, test = 0.95,
                   n.cores = 1)


### 4. Interpreting the results ###

summary(sea1)
print(sea1)

par(mfrow = c(1, 1), mar = c(5, 4, 4, 2) + 0.1)  # Default margins
plot_microsynth(sea1)

### 5. Adding advanced techniques ###

set.seed(123456) 
sea2 <- microsynth(seattledmi, idvar = "ID", timevar = "time",
                   intvar = "Intervention", start.pre = 1, end.pre = 12,
                   end.post = 16, match.out = match.out, match.covar = cov.var, 
                   result.var = match.out, jack = TRUE, perm = 250, test = 0.95,
                   cal.epsilon = 1e-05, n.cores = 1)

summary(sea2)
print(sea2)


plot_microsynth(sea2)

